tabmat package
========================

.. autofunction:: tabmat.from_pandas

.. autofunction:: tabmat.from_csc

.. autoclass:: tabmat.MatrixBase
   :members:
   :show-inheritance:

.. autoclass:: tabmat.DenseMatrix
   :members:
   :show-inheritance:

.. autoclass:: tabmat.SparseMatrix
   :members:
   :show-inheritance:

.. autoclass:: tabmat.CategoricalMatrix
   :members:
   :show-inheritance:

.. autoclass:: tabmat.SplitMatrix
   :members:
   :show-inheritance:

.. autoclass:: tabmat.StandardizedMatrix
   :members:
   :show-inheritance:
